colour.phenomenons — Colour 0.3.0 documentation

# Source code for colour.phenomenons

    #!/usr/bin/env python
    # -*- coding: utf-8 -*-

    from __future__ import absolute_import

    from .rayleigh import (
        scattering_cross_section,
        rayleigh_optical_depth,
        rayleigh_scattering,
        rayleigh_scattering_spd)

    __all__ = ['scattering_cross_section',
               'rayleigh_optical_depth',
               'rayleigh_scattering',
               'rayleigh_scattering_spd']